@@ -29,12 +29,17 @@ var NAVTREE =
       [ "What is an Entity Component System?", "index.html#what-is-an-entity-component-system", null ],
       [ "Show me the code!", "index.html#show-me-the-code", null ],
       [ "Projects using Flecs", "index.html#projects-using-flecs", [
-        [ "Hytale", "index.html#hytalehttpshytalecom", null ],
         [ "Tempest Rising", "index.html#tempest-rising", null ],
         [ "Territory Control 2", "index.html#territory-control-2", null ],
+        [ "Resistance is Brutal", "index.html#resistance-is-brutal", null ],
+        [ "Age of Respair", "index.html#age-of-respair", null ],
+        [ "FEAST", "index.html#feast", null ],
         [ "The Forge", "index.html#the-forge", null ],
         [ "Extermination Shock", "index.html#extermination-shock", null ],
+        [ "ECS survivors", "index.html#ecs-survivors", null ],
+        [ "Ascendant", "index.html#ascendant", null ],
         [ "Tome Tumble Tournament", "index.html#tome-tumble-tournament", null ],
+        [ "Hyperion Minecraft Server", "index.html#hyperion-minecraft-server", null ],
         [ "Sol Survivor", "index.html#sol-survivor", null ],
         [ "Equilibrium Engine", "index.html#equilibrium-engine", null ],
         [ "After Sun", "index.html#after-sun", null ],
@@ -46,7 +51,8 @@ var NAVTREE =
       [ "Manuals", "md_docs_2Docs.html#manuals", null ],
       [ "API reference", "md_docs_2Docs.html#api-reference", null ],
       [ "Examples", "md_docs_2Docs.html#examples", null ],
-      [ "Demos", "md_docs_2Docs.html#demos", null ],
+      [ "Videos", "md_docs_2Docs.html#videos", null ],
+      [ "Open Source Projects", "md_docs_2Docs.html#open-source-projects", null ],
       [ "Articles", "md_docs_2Docs.html#articles", null ],
       [ "Resources", "md_docs_2Docs.html#resources", [
         [ "Resources provided by the community", "md_docs_2Docs.html#resources-provided-by-the-community", null ],
@@ -67,7 +73,7 @@ var NAVTREE =
       [ "Can Flecs be compiled to web assembly?", "md_docs_2FAQ.html#can-flecs-be-compiled-to-web-assembly", null ],
       [ "Why am I getting an “use of undeclared identifier 'FLECS_ID …’” compiler error?", "md_docs_2FAQ.html#why-am-i-getting-an-use-of-undeclared-identifier-flecs_id--compiler-error", null ],
       [ "Why are my entity ids so large?", "md_docs_2FAQ.html#why-are-my-entity-ids-so-large", null ],
-      [ "What is the difference between add & set? Why do both exist?", "md_docs_2FAQ.html#what-is-the-difference-between-add--set-why-do-both-exist", null ],
+      [ "What is the difference between add &amp; set? Why do both exist?", "md_docs_2FAQ.html#what-is-the-difference-between-add--set-why-do-both-exist", null ],
       [ "Can Flecs serialize components?", "md_docs_2FAQ.html#can-flecs-serialize-components", null ],
       [ "Why is Flecs so large?", "md_docs_2FAQ.html#why-is-flecs-so-large", null ],
       [ "Why does the explorer not work?", "md_docs_2FAQ.html#why-does-the-explorer-not-work", null ],
@@ -90,7 +96,9 @@ var NAVTREE =
         [ "Running tests (bake)", "md_docs_2Quickstart.html#running-tests-bake", [
           [ "Running tests (cmake, experimental)", "md_docs_2Quickstart.html#running-tests-cmake-experimental", null ]
         ] ],
-        [ "Emscripten", "md_docs_2Quickstart.html#emscripten", null ],
+        [ "Emscripten", "md_docs_2Quickstart.html#emscripten", null ]
+      ] ],
+      [ "Android(cmake)", "md_docs_2Quickstart.html#androidcmake", [
         [ "Addons", "md_docs_2Quickstart.html#addons", null ]
       ] ],
       [ "Concepts", "md_docs_2Quickstart.html#concepts", [
@@ -186,7 +194,7 @@ var NAVTREE =
           [ "All", "md_docs_2Queries.html#all", null ],
           [ "None", "md_docs_2Queries.html#none", null ]
         ] ],
-        [ "Performance tips & tricks", "md_docs_2Queries.html#performance-tips--tricks", [
+        [ "Performance tips &amp; tricks", "md_docs_2Queries.html#performance-tips--tricks", [
           [ "Rematching", "md_docs_2Queries.html#rematching", null ],
           [ "Empty archetype optimization", "md_docs_2Queries.html#empty-archetype-optimization", null ]
         ] ]
@@ -210,12 +218,11 @@ var NAVTREE =
         [ "Singletons", "md_docs_2Queries.html#singletons-1", null ],
         [ "Relationship Traversal", "md_docs_2Queries.html#relationship-traversal", [
           [ "Traversal Flags", "md_docs_2Queries.html#traversal-flags", null ],
-          [ "Iteration", "md_docs_2Queries.html#iteration-1", null ],
           [ "Limitations", "md_docs_2Queries.html#limitations", null ]
         ] ],
         [ "Variables", "md_docs_2Queries.html#variables", [
-          [ "Setting Variables", "md_docs_2Queries.html#setting-variables", null ],
-          [ "Lookup variables", "md_docs_2Queries.html#lookup-variables", null ]
+          [ "Lookup variables", "md_docs_2Queries.html#lookup-variables", null ],
+          [ "Setting Variables", "md_docs_2Queries.html#setting-variables", null ]
         ] ],
         [ "Member Value Queries", "md_docs_2Queries.html#member-value-queries", null ],
         [ "Change Detection", "md_docs_2Queries.html#change-detection", null ],
@@ -302,8 +309,8 @@ var NAVTREE =
           [ "Observers vs. Hooks", "md_docs_2ObserversManual.html#observers-vs-hooks", null ]
         ] ],
         [ "OnAdd Events", "md_docs_2ObserversManual.html#onadd-events", null ],
-        [ "OnSet Events", "md_docs_2ObserversManual.html#onset-events", null ],
-        [ "OnSet and Inheritance", "md_docs_2ObserversManual.html#onset-and-inheritance", [
+        [ "OnSet Events", "md_docs_2ObserversManual.html#onset-events", [
+          [ "OnSet and Inheritance", "md_docs_2ObserversManual.html#onset-and-inheritance", null ],
           [ "Adding an IsA pair", "md_docs_2ObserversManual.html#adding-an-isa-pair", null ],
           [ "Removing an Override", "md_docs_2ObserversManual.html#removing-an-override", null ],
           [ "Setting an Inherited Component", "md_docs_2ObserversManual.html#setting-an-inherited-component", null ]
@@ -313,11 +320,14 @@ var NAVTREE =
       [ "Multi-event Observers", "md_docs_2ObserversManual.html#multi-event-observers", null ],
       [ "Multi-term Observers", "md_docs_2ObserversManual.html#multi-term-observers", [
         [ "Filter Terms", "md_docs_2ObserversManual.html#filter-terms", null ],
+        [ "Query variables", "md_docs_2ObserversManual.html#query-variables", null ],
         [ "Event Downgrading", "md_docs_2ObserversManual.html#event-downgrading", null ],
         [ "Event Inversion", "md_docs_2ObserversManual.html#event-inversion", null ]
       ] ],
       [ "Monitors", "md_docs_2ObserversManual.html#monitors", null ],
-      [ "Yield Existing", "md_docs_2ObserversManual.html#yield-existing", null ],
+      [ "Yield Existing", "md_docs_2ObserversManual.html#yield-existing", [
+        [ "Yield_existing flags", "md_docs_2ObserversManual.html#yield_existing-flags", null ]
+      ] ],
       [ "Fixed Source Terms", "md_docs_2ObserversManual.html#fixed-source-terms", [
         [ "Singletons", "md_docs_2ObserversManual.html#singletons-2", null ]
       ] ],
@@ -332,7 +342,7 @@ var NAVTREE =
         [ "Observer Ordering", "md_docs_2ObserversManual.html#observer-ordering", [
           [ "Observer order is undefined", "md_docs_2ObserversManual.html#observer-order-is-undefined", null ],
           [ "Event order is undefined between entities", "md_docs_2ObserversManual.html#event-order-is-undefined-between-entities", null ],
-          [ "OnAdd & OnRemove order is undefined", "md_docs_2ObserversManual.html#onadd--onremove-order-is-undefined", null ],
+          [ "OnAdd &amp; OnRemove order is undefined", "md_docs_2ObserversManual.html#onadd--onremove-order-is-undefined", null ],
           [ "OnSet order is maintained", "md_docs_2ObserversManual.html#onset-order-is-maintained", null ],
           [ "Custom event order is maintained", "md_docs_2ObserversManual.html#custom-event-order-is-maintained", null ],
           [ "Hooks and Events", "md_docs_2ObserversManual.html#hooks-and-events", null ],
@@ -368,6 +378,8 @@ var NAVTREE =
       [ "Target trait", "md_docs_2ComponentTraits.html#target-trait", null ],
       [ "PairIsTag trait", "md_docs_2ComponentTraits.html#pairistag-trait", null ],
       [ "Final trait", "md_docs_2ComponentTraits.html#final-trait", null ],
+      [ "Inheritable trait", "md_docs_2ComponentTraits.html#inheritable-trait", null ],
+      [ "OrderedChildren trait", "md_docs_2ComponentTraits.html#orderedchildren-trait", null ],
       [ "OnInstantiate trait", "md_docs_2ComponentTraits.html#oninstantiate-trait", [
         [ "Override", "md_docs_2ComponentTraits.html#override", null ],
         [ "Inherit", "md_docs_2ComponentTraits.html#inherit", null ],
@@ -379,8 +391,8 @@ var NAVTREE =
       [ "Traversable trait", "md_docs_2ComponentTraits.html#traversable-trait", null ],
       [ "Exclusive trait", "md_docs_2ComponentTraits.html#exclusive-trait", null ],
       [ "CanToggle trait", "md_docs_2ComponentTraits.html#cantoggle-trait", null ],
-      [ "Union trait", "md_docs_2ComponentTraits.html#union-trait", null ],
       [ "Sparse trait", "md_docs_2ComponentTraits.html#sparse-trait", null ],
+      [ "DontFragment trait", "md_docs_2ComponentTraits.html#dontfragment-trait", null ],
       [ "Symmetric trait", "md_docs_2ComponentTraits.html#symmetric-trait", null ],
       [ "With trait", "md_docs_2ComponentTraits.html#with-trait", null ],
       [ "OneOf trait", "md_docs_2ComponentTraits.html#oneof-trait", null ]
@@ -441,6 +453,23 @@ var NAVTREE =
         [ "Inheritance", "md_docs_2FlecsScript.html#inheritance", null ],
         [ "Relationship hierarchies", "md_docs_2FlecsScript.html#relationship-hierarchies", null ]
       ] ],
+      [ "Expressions", "md_docs_2FlecsScript.html#expressions", [
+        [ "Operators", "md_docs_2FlecsScript.html#operators-1", null ],
+        [ "Values", "md_docs_2FlecsScript.html#values", [
+          [ "Initializers", "md_docs_2FlecsScript.html#initializers", null ]
+        ] ],
+        [ "Match expressions", "md_docs_2FlecsScript.html#match-expressions", null ],
+        [ "String interpolation", "md_docs_2FlecsScript.html#string-interpolation", null ],
+        [ "Types", "md_docs_2FlecsScript.html#types", [
+          [ "Unary expressions", "md_docs_2FlecsScript.html#unary-expressions", null ],
+          [ "Binary expressions", "md_docs_2FlecsScript.html#binary-expressions", null ],
+          [ "Lvalues", "md_docs_2FlecsScript.html#lvalues", null ]
+        ] ],
+        [ "Functions", "md_docs_2FlecsScript.html#functions", null ],
+        [ "Methods", "md_docs_2FlecsScript.html#methods", null ],
+        [ "Builtin functions and constants", "md_docs_2FlecsScript.html#builtin-functions-and-constants", null ]
+      ] ],
+      [ "Templates", "md_docs_2FlecsScript.html#templates", null ],
       [ "Advanced Features", "md_docs_2FlecsScript.html#advanced-features", [
         [ "Module statement", "md_docs_2FlecsScript.html#module-statement", null ],
         [ "Using statement", "md_docs_2FlecsScript.html#using-statement", null ],
@@ -448,28 +477,28 @@ var NAVTREE =
         [ "Variables", "md_docs_2FlecsScript.html#variables-2", null ],
         [ "Component values", "md_docs_2FlecsScript.html#component-values", null ],
         [ "If statement", "md_docs_2FlecsScript.html#if-statement", null ],
+        [ "For statement", "md_docs_2FlecsScript.html#for-statement", null ],
         [ "Default components", "md_docs_2FlecsScript.html#default-components", null ],
-        [ "Semicolon operator", "md_docs_2FlecsScript.html#semicolon-operator", null ]
+        [ "Semicolon operator", "md_docs_2FlecsScript.html#semicolon-operator", null ],
+        [ "Comma operator", "md_docs_2FlecsScript.html#comma-operator", null ]
       ] ],
-      [ "Comma operator", "md_docs_2FlecsScript.html#comma-operator", null ],
-      [ "Templates", "md_docs_2FlecsScript.html#templates", null ],
       [ "API", "md_docs_2FlecsScript.html#api", [
         [ "Run once", "md_docs_2FlecsScript.html#run-once", null ],
         [ "Run multiple times", "md_docs_2FlecsScript.html#run-multiple-times", null ],
         [ "Managed script", "md_docs_2FlecsScript.html#managed-script", null ]
       ] ]
     ] ],
-    [ "FlecsScriptTutorial", "flecsscripttutorial.html", [
-      [ "Flecs Script Tutorial", "flecsscripttutorial.html#flecs-script-tutorial", [
-        [ "Getting Started with the Explorer", "flecsscripttutorial.html#getting-started-with-the-explorer", null ],
-        [ "The Basics", "flecsscripttutorial.html#the-basics-3", null ],
-        [ "Adding Components", "flecsscripttutorial.html#adding-components", null ],
-        [ "Drawing Shapes", "flecsscripttutorial.html#drawing-shapes", null ],
-        [ "Drawing a Fence", "flecsscripttutorial.html#drawing-a-fence", null ],
-        [ "Prefabs", "flecsscripttutorial.html#prefabs-1", null ],
-        [ "Templates", "flecsscripttutorial.html#templates-1", null ],
-        [ "Grids", "flecsscripttutorial.html#grids", null ],
-        [ "Nested Templates", "flecsscripttutorial.html#nested-templates", null ]
+    [ "FlecsScriptTutorial", "md_docs_2FlecsScriptTutorial.html", [
+      [ "Flecs Script Tutorial", "md_docs_2FlecsScriptTutorial.html#flecs-script-tutorial", [
+        [ "Getting Started with the Explorer", "md_docs_2FlecsScriptTutorial.html#getting-started-with-the-explorer", null ],
+        [ "The Basics", "md_docs_2FlecsScriptTutorial.html#the-basics-3", null ],
+        [ "Adding Components", "md_docs_2FlecsScriptTutorial.html#adding-components", null ],
+        [ "Drawing Shapes", "md_docs_2FlecsScriptTutorial.html#drawing-shapes", null ],
+        [ "Drawing a Fence", "md_docs_2FlecsScriptTutorial.html#drawing-a-fence", null ],
+        [ "Prefabs", "md_docs_2FlecsScriptTutorial.html#prefabs-1", null ],
+        [ "Templates", "md_docs_2FlecsScriptTutorial.html#templates-1", null ],
+        [ "Grids", "md_docs_2FlecsScriptTutorial.html#grids", null ],
+        [ "Nested Templates", "md_docs_2FlecsScriptTutorial.html#nested-templates", null ]
       ] ]
     ] ],
     [ "Flecs Remote API", "md_docs_2FlecsRemoteApi.html", [
@@ -517,12 +546,12 @@ var NAVTREE =
     [ "Manual", "md_docs_2Manual.html", [
       [ "Introduction", "md_docs_2Manual.html#introduction-8", null ],
       [ "Design Goals", "md_docs_2Manual.html#design-goals", [
-        [ "Performance", "md_docs_2Manual.html#autotoc_md1-performance", null ],
-        [ "Portability", "md_docs_2Manual.html#autotoc_md2-portability", null ],
-        [ "Reusability", "md_docs_2Manual.html#autotoc_md3-reusability", null ],
-        [ "Usability", "md_docs_2Manual.html#autotoc_md4-usability", null ],
-        [ "Extensibility", "md_docs_2Manual.html#autotoc_md5-extensibility", null ],
-        [ "Have fun!", "md_docs_2Manual.html#autotoc_md6-have-fun", null ]
+        [ "1. Performance", "md_docs_2Manual.html#autotoc_md1-performance", null ],
+        [ "2. Portability", "md_docs_2Manual.html#autotoc_md2-portability", null ],
+        [ "3. Reusability", "md_docs_2Manual.html#autotoc_md3-reusability", null ],
+        [ "4. Usability", "md_docs_2Manual.html#autotoc_md4-usability", null ],
+        [ "5. Extensibility", "md_docs_2Manual.html#autotoc_md5-extensibility", null ],
+        [ "6. Have fun!", "md_docs_2Manual.html#autotoc_md6-have-fun", null ]
       ] ],
       [ "API design", "md_docs_2Manual.html#api-design", [
         [ "Naming conventions", "md_docs_2Manual.html#naming-conventions", null ],
@@ -542,7 +571,7 @@ var NAVTREE =
         [ "Iter function", "md_docs_2MigrationGuide.html#iter-function", null ],
         [ "Query DSL", "md_docs_2MigrationGuide.html#query-dsl", null ]
       ] ],
-      [ "Systems & Pipelines", "md_docs_2MigrationGuide.html#systems--pipelines", null ],
+      [ "Systems &amp; Pipelines", "md_docs_2MigrationGuide.html#systems--pipelines", null ],
       [ "Observers", "md_docs_2MigrationGuide.html#observers-1", null ],
       [ "Term iterators", "md_docs_2MigrationGuide.html#term-iterators", null ],
       [ "Entity Names", "md_docs_2MigrationGuide.html#entity-names-1", null ],
@@ -572,7 +601,8 @@ var NAVTREE =
       [ "Class Members", "functions.html", [
         [ "All", "functions.html", "functions_dup" ],
         [ "Functions", "functions_func.html", "functions_func" ],
-        [ "Variables", "functions_vars.html", "functions_vars" ]
+        [ "Variables", "functions_vars.html", "functions_vars" ],
+        [ "Typedefs", "functions_type.html", null ]
       ] ]
     ] ],
     [ "Files", "files.html", [
@@ -581,7 +611,7 @@ var NAVTREE =
         [ "All", "globals.html", "globals_dup" ],
         [ "Functions", "globals_func.html", "globals_func" ],
         [ "Variables", "globals_vars.html", "globals_vars" ],
-        [ "Typedefs", "globals_type.html", null ],
+        [ "Typedefs", "globals_type.html", "globals_type" ],
         [ "Enumerations", "globals_enum.html", null ],
         [ "Enumerator", "globals_eval.html", null ],
         [ "Macros", "globals_defs.html", null ]
@@ -593,24 +623,25 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "alerts_2builder__i_8hpp.html",
-"group__builtin__tags.html#ga2721d90f1d18f5afc24be955328ac51e",
-"group__c__addons__meta.html#ga65239f23769c834492a6021b382e5eba",
-"group__c__addons__units__angle.html#ga4e10977859e78046955e8764dc74dd5a",
-"group__cpp__addons__doc.html#ga4e46731c6716724a3c1450413d7ff8a3",
-"group__entities.html#gaa0ba13258a2af43b1d711a52dbf44b5f",
-"group__queries.html#ga8f9fa5807e604b848ca7bad8e63e0235",
-"md_docs_2EntitiesComponents.html",
-"md_docs_2Queries.html#optional-operator",
-"structEcsOpaque.html",
-"structecs__iter__t.html#a0fe52396b42134a758014a3f078b3742",
-"structecs__pipeline__stats__t.html#a130a4181452fa5dda3129f7f4fb440cf",
-"structecs__world__info__t.html#a402efe5be309f8c0aa544f5e1b4f3caf",
-"structflecs_1_1array__iterator.html",
-"structflecs_1_1entity__view.html#ae49ff16148128ab73dba9360c45ae16a",
-"structflecs_1_1system.html#a8c528baf37154d347366083f0f816846",
-"structflecs_1_1world.html#a1740c07c0b9f370bc12e7da0ccf5d3bd",
-"term_2mixin_8inl_source.html"
+"group__builtin__tags.html#ga429fe205a699548fedb8394fdb284854",
+"group__c__addons__meta.html#ga6dba5d1b917773290bace8041307cf3b",
+"group__c__addons__timer.html#gadb9aec2c89c51a4da664e86868b8a023",
+"group__core__types.html#gad89be37a3609d524994b418b413fa9ae",
+"group__creating__entities.html#ga0bacd1d1d6725e6abd79f0a647224a14",
+"group__paths.html#gae648e450d1cb2720f86447597fc4e292",
+"md_docs_2DesignWithFlecs.html#complex-component-data",
+"md_docs_2ObserversManual.html#event-propagation",
+"query_2decl_8hpp_source.html",
+"structecs__entity__desc__t.html#ac3216af1b28b37d478e2318390e37a4f",
+"structecs__observer__desc__t.html",
+"structecs__term__t.html#aacebdceb5defe8ea25ad6374cb1e8ab3",
+"structflecs_1_1___1_1has__operator__greater.html",
+"structflecs_1_1entity__builder.html#afc1787191dce47aa9a20af1c13840d17",
+"structflecs_1_1iterable.html",
+"structflecs_1_1units.html",
+"structflecs_1_1world.html#a7c1aa50d01758770e7d0deeb9f1cfafa"
 ];
 
-var SYNCONMSG = 'click to disable panel synchronisation';
-var SYNCOFFMSG = 'click to enable panel synchronisation';
\ No newline at end of file
+var SYNCONMSG = 'click to disable panel synchronization';
+var SYNCOFFMSG = 'click to enable panel synchronization';
+var LISTOFALLMEMBERS = 'List of all members';
\ No newline at end of file
