@@ -1,5 +1,52 @@
 var NAVTREEINDEX15 =
 {
+"structflecs_1_1iterable.html":[19,0,0,39],
+"structflecs_1_1iterable.html#a067e919a863555b18b36e6bb4bb84bb2":[18,0,0,39,3],
+"structflecs_1_1iterable.html#a067e919a863555b18b36e6bb4bb84bb2":[19,0,0,39,3],
+"structflecs_1_1iterable.html#a38b8c1f461ffccd9c7e80671a310164a":[18,0,0,39,8],
+"structflecs_1_1iterable.html#a38b8c1f461ffccd9c7e80671a310164a":[19,0,0,39,8],
+"structflecs_1_1iterable.html#a39148a144dd207205428785fc9499360":[18,0,0,39,2],
+"structflecs_1_1iterable.html#a39148a144dd207205428785fc9499360":[19,0,0,39,2],
+"structflecs_1_1iterable.html#a488340ac8da3797ff7fafc527401d1f5":[18,0,0,39,1],
+"structflecs_1_1iterable.html#a488340ac8da3797ff7fafc527401d1f5":[19,0,0,39,1],
+"structflecs_1_1iterable.html#a69921d5fb6492c403ee2e1acd6c82a64":[18,0,0,39,0],
+"structflecs_1_1iterable.html#a69921d5fb6492c403ee2e1acd6c82a64":[19,0,0,39,0],
+"structflecs_1_1iterable.html#a7991ffa295bb06772c5eed88c74d0765":[18,0,0,39,4],
+"structflecs_1_1iterable.html#a7991ffa295bb06772c5eed88c74d0765":[19,0,0,39,4],
+"structflecs_1_1iterable.html#a81bef7274bf6a204b5bbb4ce13cd3a00":[18,0,0,39,7],
+"structflecs_1_1iterable.html#a81bef7274bf6a204b5bbb4ce13cd3a00":[19,0,0,39,7],
+"structflecs_1_1iterable.html#ad2a621062d20fe69515a3f569ff0f688":[18,0,0,39,5],
+"structflecs_1_1iterable.html#ad2a621062d20fe69515a3f569ff0f688":[19,0,0,39,5],
+"structflecs_1_1iterable.html#ad41e466368bf44d193b302a604463926":[18,0,0,39,9],
+"structflecs_1_1iterable.html#ad41e466368bf44d193b302a604463926":[19,0,0,39,9],
+"structflecs_1_1iterable.html#aeda598ce08dd5e13f102a5a82627660d":[18,0,0,39,6],
+"structflecs_1_1iterable.html#aeda598ce08dd5e13f102a5a82627660d":[19,0,0,39,6],
+"structflecs_1_1metric__builder.html":[17,1,1,7,0],
+"structflecs_1_1metrics.html":[17,1,1,7,1],
+"structflecs_1_1metrics_1_1Counter.html":[17,1,1,7,1,0],
+"structflecs_1_1metrics_1_1CounterId.html":[17,1,1,7,1,1],
+"structflecs_1_1metrics_1_1CounterIncrement.html":[17,1,1,7,1,2],
+"structflecs_1_1metrics_1_1Gauge.html":[17,1,1,7,1,3],
+"structflecs_1_1metrics_1_1Instance.html":[17,1,1,7,1,4],
+"structflecs_1_1metrics_1_1Metric.html":[17,1,1,7,1,5],
+"structflecs_1_1observer.html":[18,0,0,42],
+"structflecs_1_1observer.html":[19,0,0,42],
+"structflecs_1_1observer.html#a5507fae8c3f326e957f468372b63b322":[18,0,0,42,3],
+"structflecs_1_1observer.html#a5507fae8c3f326e957f468372b63b322":[19,0,0,42,3],
+"structflecs_1_1observer.html#a8baaadf7cffb365c70109d5b00e54fea":[18,0,0,42,0],
+"structflecs_1_1observer.html#a8baaadf7cffb365c70109d5b00e54fea":[19,0,0,42,0],
+"structflecs_1_1observer.html#a9d2361efe2ea358b3bd0728408ced507":[18,0,0,42,1],
+"structflecs_1_1observer.html#a9d2361efe2ea358b3bd0728408ced507":[19,0,0,42,1],
+"structflecs_1_1observer.html#ac343dbb0c6a3cd44bd97863127a1c2a0":[18,0,0,42,4],
+"structflecs_1_1observer.html#ac343dbb0c6a3cd44bd97863127a1c2a0":[19,0,0,42,4],
+"structflecs_1_1observer.html#ac475621a5fb9513885c12474ba7ffd67":[18,0,0,42,2],
+"structflecs_1_1observer.html#ac475621a5fb9513885c12474ba7ffd67":[19,0,0,42,2],
+"structflecs_1_1observer__builder.html":[17,1,0,6,0],
+"structflecs_1_1observer__builder__i.html":[17,1,0,6,1],
+"structflecs_1_1observer__builder__i.html#a29a3a437f099c7cf33e723c8b38e0200":[17,1,0,6,1,1],
+"structflecs_1_1observer__builder__i.html#a75a45fd36b7658b358b087214256054e":[17,1,0,6,1,0],
+"structflecs_1_1observer__builder__i.html#a7db637ba43781d03f5aa212ce6435898":[17,1,0,6,1,5],
+"structflecs_1_1observer__builder__i.html#a8fc22ab70ec2cf5bdfc098c89e386979":[17,1,0,6,1,4],
 "structflecs_1_1observer__builder__i.html#ab88bcb57f143d7949961c5bc8d306ba4":[17,1,0,6,1,2],
 "structflecs_1_1observer__builder__i.html#ae5c6a5cdd3ab8ebb717ff09dd486016a":[17,1,0,6,1,3],
 "structflecs_1_1opaque.html":[17,1,1,6,2],
@@ -130,36 +177,48 @@ var NAVTREEINDEX15 =
 "structflecs_1_1system__runner__fluent.html":[18,0,0,68],
 "structflecs_1_1system__runner__fluent.html":[19,0,0,68],
 "structflecs_1_1table.html":[17,1,0,10,0],
-"structflecs_1_1table.html#a058d61966f00499d053dff8039ca2a14":[17,1,0,10,0,9],
-"structflecs_1_1table.html#a058d61966f00499d053dff8039ca2a14":[17,1,0,10,0,10],
-"structflecs_1_1table.html#a0ba8f314ee6c96666b1afeb64ac79cff":[17,1,0,10,0,27],
-"structflecs_1_1table.html#a23a1a69a3823e8af7d7d74145b9a88e5":[17,1,0,10,0,14],
-"structflecs_1_1table.html#a3addc38d0cf88585616afe51cc8853d1":[17,1,0,10,0,23],
-"structflecs_1_1table.html#a3d2a9da3c934c6a6b0ceb41b77f87dd0":[17,1,0,10,0,4],
-"structflecs_1_1table.html#a46596c59b11cf7d33985d614bbc2e0c4":[17,1,0,10,0,22],
-"structflecs_1_1table.html#a4ac3c3a5356120d88fa0595abd795806":[17,1,0,10,0,26],
-"structflecs_1_1table.html#a5fb29e445a1bb0ea414e2ec83b2baf69":[17,1,0,10,0,6],
-"structflecs_1_1table.html#a6b3e63ca7949245b91cd0f8e9e4d7460":[17,1,0,10,0,21],
-"structflecs_1_1table.html#a70a89bf782301418ca4e15c2567e7a03":[17,1,0,10,0,15],
-"structflecs_1_1table.html#a8372484d6d5ec13562dd8e254e2d8d77":[17,1,0,10,0,7],
-"structflecs_1_1table.html#a86e3759ef7c77e81c16f2e70b275d020":[17,1,0,10,0,25],
-"structflecs_1_1table.html#a9655448c49fe03f6b6523c78dc8e4080":[17,1,0,10,0,1],
-"structflecs_1_1table.html#aa014eb60fd0c3c7af006a6e4a1f180c7":[17,1,0,10,0,20],
-"structflecs_1_1table.html#aa2263989b460522acc34a5c42cfa4e3d":[17,1,0,10,0,12],
-"structflecs_1_1table.html#aa5ab36509205123fe711fd283d14fd4e":[17,1,0,10,0,13],
-"structflecs_1_1table.html#aa6b351010d0d6741f029186d53ccb6d0":[17,1,0,10,0,3],
-"structflecs_1_1table.html#aa6e234e831ed8b2b6c4caad2f66f6195":[17,1,0,10,0,18],
-"structflecs_1_1table.html#aaad016dd19a1bf71d05b172d5e320e0e":[17,1,0,10,0,19],
-"structflecs_1_1table.html#aac9c20bbb66b6af3cc68d8e34c76e256":[17,1,0,10,0,8],
-"structflecs_1_1table.html#aad53f41c1f323b1a56d82b621c799890":[17,1,0,10,0,17],
-"structflecs_1_1table.html#ab0aa4120213957d2d054172cc0146452":[17,1,0,10,0,29],
-"structflecs_1_1table.html#ab924cc62a25767642701f82e72aedde6":[17,1,0,10,0,0],
-"structflecs_1_1table.html#abdfefc34e5ac22e911c4fd83ba199f90":[17,1,0,10,0,24],
-"structflecs_1_1table.html#ac30c5eaa596849a87323c0f607dd1056":[17,1,0,10,0,2],
-"structflecs_1_1table.html#ae7a54c5abb506d37cd2829f72d6053a2":[17,1,0,10,0,5],
-"structflecs_1_1table.html#ae956a7de8e2557ad9a58eaa82e9d3a9c":[17,1,0,10,0,11],
-"structflecs_1_1table.html#aedaa7ca245abe5493dce9f81f1141db3":[17,1,0,10,0,16],
-"structflecs_1_1table.html#afe7c6dc00196a80f1dac662074d105a5":[17,1,0,10,0,28],
+"structflecs_1_1table.html#a058d61966f00499d053dff8039ca2a14":[17,1,0,10,0,11],
+"structflecs_1_1table.html#a0ba8f314ee6c96666b1afeb64ac79cff":[17,1,0,10,0,38],
+"structflecs_1_1table.html#a18529c80e6dc4744eb36ba2f4fcb41fa":[17,1,0,10,0,8],
+"structflecs_1_1table.html#a23a1a69a3823e8af7d7d74145b9a88e5":[17,1,0,10,0,15],
+"structflecs_1_1table.html#a2eb13746e1943c63e014c4e59565d3b7":[17,1,0,10,0,31],
+"structflecs_1_1table.html#a391da4a3d93c557f89ce971339bfd484":[17,1,0,10,0,25],
+"structflecs_1_1table.html#a3addc38d0cf88585616afe51cc8853d1":[17,1,0,10,0,29],
+"structflecs_1_1table.html#a3d2a9da3c934c6a6b0ceb41b77f87dd0":[17,1,0,10,0,5],
+"structflecs_1_1table.html#a41127bfbc8387ff9f7ae75efd250eca8":[17,1,0,10,0,30],
+"structflecs_1_1table.html#a46596c59b11cf7d33985d614bbc2e0c4":[17,1,0,10,0,23],
+"structflecs_1_1table.html#a4ac3c3a5356120d88fa0595abd795806":[17,1,0,10,0,37],
+"structflecs_1_1table.html#a5b98f3b29642acbf5e3e8a415755c18a":[17,1,0,10,0,9],
+"structflecs_1_1table.html#a5fb29e445a1bb0ea414e2ec83b2baf69":[17,1,0,10,0,7],
+"structflecs_1_1table.html#a6b3e63ca7949245b91cd0f8e9e4d7460":[17,1,0,10,0,22],
+"structflecs_1_1table.html#a70a89bf782301418ca4e15c2567e7a03":[17,1,0,10,0,16],
+"structflecs_1_1table.html#a7e4635443500e9b4cd0fb1b548dac494":[17,1,0,10,0,33],
+"structflecs_1_1table.html#a86e3759ef7c77e81c16f2e70b275d020":[17,1,0,10,0,36],
+"structflecs_1_1table.html#a9655448c49fe03f6b6523c78dc8e4080":[17,1,0,10,0,2],
+"structflecs_1_1table.html#a998d502aefee206d45679caa8d3ef790":[17,1,0,10,0,24],
+"structflecs_1_1table.html#a9be3754213300919d1000d5ac6e76e77":[17,1,0,10,0,10],
+"structflecs_1_1table.html#aa014eb60fd0c3c7af006a6e4a1f180c7":[17,1,0,10,0,21],
+"structflecs_1_1table.html#aa2263989b460522acc34a5c42cfa4e3d":[17,1,0,10,0,13],
+"structflecs_1_1table.html#aa5ab36509205123fe711fd283d14fd4e":[17,1,0,10,0,14],
+"structflecs_1_1table.html#aa6b351010d0d6741f029186d53ccb6d0":[17,1,0,10,0,4],
+"structflecs_1_1table.html#aa6e234e831ed8b2b6c4caad2f66f6195":[17,1,0,10,0,19],
+"structflecs_1_1table.html#aa83e4f00911cebed74fd4c8f5115aaeb":[17,1,0,10,0,26],
+"structflecs_1_1table.html#aa98cae939b29ebee95756e8e7d191496":[17,1,0,10,0,32],
+"structflecs_1_1table.html#aaad016dd19a1bf71d05b172d5e320e0e":[17,1,0,10,0,20],
+"structflecs_1_1table.html#aad53f41c1f323b1a56d82b621c799890":[17,1,0,10,0,18],
+"structflecs_1_1table.html#aae791c154f1964bb89f25bb025522d75":[17,1,0,10,0,6],
+"structflecs_1_1table.html#ab0aa4120213957d2d054172cc0146452":[17,1,0,10,0,40],
+"structflecs_1_1table.html#ab924cc62a25767642701f82e72aedde6":[17,1,0,10,0,1],
+"structflecs_1_1table.html#abbef25a1cb1cece5bfc5566e1b7430b2":[17,1,0,10,0,0],
+"structflecs_1_1table.html#abdfefc34e5ac22e911c4fd83ba199f90":[17,1,0,10,0,35],
+"structflecs_1_1table.html#ac30c5eaa596849a87323c0f607dd1056":[17,1,0,10,0,3],
+"structflecs_1_1table.html#ace4c034dd0866a298240f1a54a3edf6e":[17,1,0,10,0,28],
+"structflecs_1_1table.html#ad20b724b9976d61664696e0a9e1de8df":[17,1,0,10,0,27],
+"structflecs_1_1table.html#ae5621588f4ba16574f7f783d32f69b06":[17,1,0,10,0,41],
+"structflecs_1_1table.html#ae956a7de8e2557ad9a58eaa82e9d3a9c":[17,1,0,10,0,12],
+"structflecs_1_1table.html#aedaa7ca245abe5493dce9f81f1141db3":[17,1,0,10,0,17],
+"structflecs_1_1table.html#af1803fd2a57cd81e8c023a8b912f3b91":[17,1,0,10,0,34],
+"structflecs_1_1table.html#afe7c6dc00196a80f1dac662074d105a5":[17,1,0,10,0,39],
 "structflecs_1_1table__range.html":[17,1,0,10,1],
 "structflecs_1_1table__range.html#a764251bd886d3b316870b07bf2d2adf0":[17,1,0,10,1,0],
 "structflecs_1_1term.html":[17,1,0,7,5],
@@ -190,64 +249,5 @@ var NAVTREEINDEX15 =
 "structflecs_1_1timer.html#ac475621a5fb9513885c12474ba7ffd67":[18,0,0,74,2],
 "structflecs_1_1timer.html#ac475621a5fb9513885c12474ba7ffd67":[19,0,0,74,2],
 "structflecs_1_1type.html":[17,1,0,11,0],
-"structflecs_1_1units.html":[18,0,0,76],
-"structflecs_1_1units.html":[19,0,0,76],
-"structflecs_1_1units_1_1Amount.html":[17,1,1,15,1,6],
-"structflecs_1_1units_1_1Angle.html":[17,1,1,15,1,13],
-"structflecs_1_1units_1_1Atto.html":[17,1,1,15,0,2],
-"structflecs_1_1units_1_1Bel.html":[17,1,1,15,38],
-"structflecs_1_1units_1_1Centi.html":[17,1,1,15,0,8],
-"structflecs_1_1units_1_1Color.html":[17,1,1,15,1,16],
-"structflecs_1_1units_1_1Data.html":[17,1,1,15,1,11],
-"structflecs_1_1units_1_1DataRate.html":[17,1,1,15,1,12],
-"structflecs_1_1units_1_1Deca.html":[17,1,1,15,0,10],
-"structflecs_1_1units_1_1Deci.html":[17,1,1,15,0,9],
-"structflecs_1_1units_1_1DeciBel.html":[17,1,1,15,39],
-"structflecs_1_1units_1_1Duration.html":[17,1,1,15,1,0],
-"structflecs_1_1units_1_1ElectricCurrent.html":[17,1,1,15,1,3],
-"structflecs_1_1units_1_1Exa.html":[17,1,1,15,0,17],
-"structflecs_1_1units_1_1Exbi.html":[17,1,1,15,0,25],
-"structflecs_1_1units_1_1Femto.html":[17,1,1,15,0,3],
-"structflecs_1_1units_1_1Force.html":[17,1,1,15,1,5],
-"structflecs_1_1units_1_1Frequency.html":[17,1,1,15,1,14],
-"structflecs_1_1units_1_1Gibi.html":[17,1,1,15,0,22],
-"structflecs_1_1units_1_1Giga.html":[17,1,1,15,0,14],
-"structflecs_1_1units_1_1Hecto.html":[17,1,1,15,0,11],
-"structflecs_1_1units_1_1Kibi.html":[17,1,1,15,0,20],
-"structflecs_1_1units_1_1Kilo.html":[17,1,1,15,0,12],
-"structflecs_1_1units_1_1Length.html":[17,1,1,15,1,7],
-"structflecs_1_1units_1_1LuminousIntensity.html":[17,1,1,15,1,4],
-"structflecs_1_1units_1_1Mass.html":[17,1,1,15,1,2],
-"structflecs_1_1units_1_1Mebi.html":[17,1,1,15,0,21],
-"structflecs_1_1units_1_1Mega.html":[17,1,1,15,0,13],
-"structflecs_1_1units_1_1Micro.html":[17,1,1,15,0,6],
-"structflecs_1_1units_1_1Milli.html":[17,1,1,15,0,7],
-"structflecs_1_1units_1_1Nano.html":[17,1,1,15,0,5],
-"structflecs_1_1units_1_1Pebi.html":[17,1,1,15,0,24],
-"structflecs_1_1units_1_1Percentage.html":[17,1,1,15,37],
-"structflecs_1_1units_1_1Peta.html":[17,1,1,15,0,16],
-"structflecs_1_1units_1_1Pico.html":[17,1,1,15,0,4],
-"structflecs_1_1units_1_1Prefixes.html":[17,1,1,15,19],
-"structflecs_1_1units_1_1Pressure.html":[17,1,1,15,1,8],
-"structflecs_1_1units_1_1Speed.html":[17,1,1,15,1,9],
-"structflecs_1_1units_1_1Tebi.html":[17,1,1,15,0,23],
-"structflecs_1_1units_1_1Temperature.html":[17,1,1,15,1,10],
-"structflecs_1_1units_1_1Tera.html":[17,1,1,15,0,15],
-"structflecs_1_1units_1_1Time.html":[17,1,1,15,1,1],
-"structflecs_1_1units_1_1Uri.html":[17,1,1,15,1,15],
-"structflecs_1_1units_1_1Yobi.html":[17,1,1,15,0,27],
-"structflecs_1_1units_1_1Yocto.html":[17,1,1,15,0,0],
-"structflecs_1_1units_1_1Yotta.html":[17,1,1,15,0,19],
-"structflecs_1_1units_1_1Zebi.html":[17,1,1,15,0,26],
-"structflecs_1_1units_1_1Zepto.html":[17,1,1,15,0,1],
-"structflecs_1_1units_1_1Zetta.html":[17,1,1,15,0,18],
-"structflecs_1_1units_1_1amount.html":[17,1,1,15,25],
-"structflecs_1_1units_1_1amount_1_1Mole.html":[17,1,1,15,7,0],
-"structflecs_1_1units_1_1angle.html":[17,1,1,15,21],
-"structflecs_1_1units_1_1angle_1_1Degrees.html":[17,1,1,15,3,1],
-"structflecs_1_1units_1_1angle_1_1Radians.html":[17,1,1,15,3,0],
-"structflecs_1_1units_1_1color.html":[17,1,1,15,36],
-"structflecs_1_1units_1_1color_1_1Css.html":[17,1,1,15,18,2],
-"structflecs_1_1units_1_1color_1_1Hsl.html":[17,1,1,15,18,1],
-"structflecs_1_1units_1_1color_1_1Rgb.html":[17,1,1,15,18,0]
+"structflecs_1_1units.html":[18,0,0,76]
 };
