@@ -1,25 +1,17 @@
 var NAVTREEINDEX5 =
 {
-"group__cpp__ref.html":[17,1,0,9],
-"group__cpp__tables.html":[17,1,0,10],
-"group__cpp__types.html":[17,1,0,11],
-"group__cpp__types.html#ga187b1f45cfe346667116cd372589f403":[17,1,0,11,1],
-"group__cpp__types.html#ga516c4b14c449bfcfdefecddad427e5be":[17,1,0,11,2],
-"group__cpp__types.html#ga566e2599001615de42a42652ba893fb4":[17,1,0,11,5],
-"group__cpp__types.html#ga603e8cbcc6f3e5a2d81aba7a96212cba":[17,1,0,11,4],
-"group__cpp__types.html#ga6e3614281a8091a6098aa30e66ab9847":[17,1,0,11,3],
-"group__cpp__world.html":[17,1,0,12],
-"group__creating__entities.html":[17,0,0,4,0],
-"group__creating__entities.html#ga0bacd1d1d6725e6abd79f0a647224a14":[17,0,0,4,0,7],
-"group__creating__entities.html#ga121c5b900576d74f970e31c78e2d4119":[17,0,0,4,0,8],
+"group__creating__entities.html#ga0bacd1d1d6725e6abd79f0a647224a14":[17,0,0,4,0,8],
+"group__creating__entities.html#ga121c5b900576d74f970e31c78e2d4119":[17,0,0,4,0,9],
+"group__creating__entities.html#ga279f4ccb3eabf1b9e81cd327c3e62938":[17,0,0,4,0,11],
 "group__creating__entities.html#ga5000a9d9624f26363d019d6ca0ea8581":[17,0,0,4,0,0],
 "group__creating__entities.html#ga56a12ac2e287f769be722ed486c5e91d":[17,0,0,4,0,2],
 "group__creating__entities.html#ga6414a4a8026ab6272bed11fde1022a5b":[17,0,0,4,0,1],
-"group__creating__entities.html#ga65137c7809b73deb979c77620defcc8f":[17,0,0,4,0,6],
+"group__creating__entities.html#ga65137c7809b73deb979c77620defcc8f":[17,0,0,4,0,7],
 "group__creating__entities.html#ga7955a95fc49aa6ba1a0ef9cec54a5fdb":[17,0,0,4,0,5],
 "group__creating__entities.html#ga82d98ec04cdc8db21bbd8294c5a603c8":[17,0,0,4,0,4],
 "group__creating__entities.html#ga9cd74d7c9e8793f65b0055b078f62804":[17,0,0,4,0,3],
-"group__creating__entities.html#gacc17c43b10bea03bcc8ec5bf738f7c9d":[17,0,0,4,0,9],
+"group__creating__entities.html#gacc17c43b10bea03bcc8ec5bf738f7c9d":[17,0,0,4,0,10],
+"group__creating__entities.html#gaebe9692adf1d483b14e1a8ab3e0ec2c1":[17,0,0,4,0,6],
 "group__each__iter.html":[17,0,0,8],
 "group__each__iter.html#ga0b563eabccb6895c42c8f392b61fefd8":[17,0,0,8,1],
 "group__each__iter.html#ga7b74ced08d518b4fe44f33a6419642b3":[17,0,0,8,3],
@@ -119,61 +111,67 @@ var NAVTREEINDEX5 =
 "group__function__types.html#gaf53455a03bb5cdfc310fa6f010fe7596":[17,0,0,1,1,18],
 "group__getting.html":[17,0,0,4,3],
 "group__getting.html#ga0d933508f6df7d9542b4db0fec805b1b":[17,0,0,4,3,4],
-"group__getting.html#ga118cecec415f322f1a1149d486355d49":[17,0,0,4,3,7],
-"group__getting.html#ga34d268a5e90289a9f5f083cb7d023409":[17,0,0,4,3,8],
+"group__getting.html#ga118cecec415f322f1a1149d486355d49":[17,0,0,4,3,8],
+"group__getting.html#ga34d268a5e90289a9f5f083cb7d023409":[17,0,0,4,3,9],
 "group__getting.html#ga6373e716c9a0f7a34e4ca44d0ef81cbc":[17,0,0,4,3,0],
 "group__getting.html#ga660bbb05421e7d0c3bbeda83608034c3":[17,0,0,4,3,1],
-"group__getting.html#ga6e512572fd150d2d2076972d8b97af6a":[17,0,0,4,3,9],
+"group__getting.html#ga6e512572fd150d2d2076972d8b97af6a":[17,0,0,4,3,10],
 "group__getting.html#ga737500b7c4eaf33d57b8912c4a3cc350":[17,0,0,4,3,2],
-"group__getting.html#ga7a69bdddf71ed21a48be414abcc49f47":[17,0,0,4,3,6],
+"group__getting.html#ga7a69bdddf71ed21a48be414abcc49f47":[17,0,0,4,3,7],
 "group__getting.html#gaa503c048b917cbb22e3edc9f5a10d64b":[17,0,0,4,3,3],
-"group__getting.html#gae303f55bf8e9ca21fc9b899041377df2":[17,0,0,4,3,5],
+"group__getting.html#gae303f55bf8e9ca21fc9b899041377df2":[17,0,0,4,3,6],
+"group__getting.html#gae81c88fdc1438f8101c74f561de668c6":[17,0,0,4,3,5],
 "group__id__flags.html":[17,0,0,2,0],
 "group__id__flags.html#ga0c145dbcbafac2d51aad296bee31093c":[17,0,0,2,0,1],
 "group__id__flags.html#ga1114992c738bb25c46fb63e6cc1f035c":[17,0,0,2,0,0],
 "group__id__flags.html#gaadca0f8f1a7f11f68d295b388f2ed86b":[17,0,0,2,0,2],
 "group__ids.html":[17,0,0,6],
-"group__ids.html#ga0cb9970c8bb6cbbf453d35f7db173cb3":[17,0,0,6,7],
-"group__ids.html#ga0fd8ba3b211dfd2e118789ed712c5fa2":[17,0,0,6,5],
+"group__ids.html#ga0cb9970c8bb6cbbf453d35f7db173cb3":[17,0,0,6,8],
+"group__ids.html#ga0fd8ba3b211dfd2e118789ed712c5fa2":[17,0,0,6,6],
 "group__ids.html#ga2e059ce947646b56b27c5d2a85bd40d9":[17,0,0,6,0],
-"group__ids.html#ga30ed23c3f2911ab2f0862fbea470e128":[17,0,0,6,9],
+"group__ids.html#ga30ed23c3f2911ab2f0862fbea470e128":[17,0,0,6,10],
 "group__ids.html#ga427c6e730abb0b59f0dbcaff282274ea":[17,0,0,6,1],
 "group__ids.html#ga4a9600458948b430b546ceadfc99d360":[17,0,0,6,4],
-"group__ids.html#ga753c113137ba666cbe0b7263a6e89f0e":[17,0,0,6,6],
-"group__ids.html#ga8a71bfce03d2f78d1fc0596468903215":[17,0,0,6,11],
-"group__ids.html#ga94e0e13d4f03ba5a073185b4a7ed3479":[17,0,0,6,10],
-"group__ids.html#gad3314cf0b367be9f34b6539987468c56":[17,0,0,6,8],
+"group__ids.html#ga753c113137ba666cbe0b7263a6e89f0e":[17,0,0,6,7],
+"group__ids.html#ga8a71bfce03d2f78d1fc0596468903215":[17,0,0,6,12],
+"group__ids.html#ga94e0e13d4f03ba5a073185b4a7ed3479":[17,0,0,6,11],
+"group__ids.html#gace0d387143f1c4792a300f8fe83c9a5f":[17,0,0,6,5],
+"group__ids.html#gad3314cf0b367be9f34b6539987468c56":[17,0,0,6,9],
 "group__ids.html#gae32a7a379694cd998137fa4fbfa49dee":[17,0,0,6,2],
 "group__ids.html#gae5b76e1c8465a67f04f5c7e48c845f8e":[17,0,0,6,3],
 "group__iterator.html":[17,0,0,10],
 "group__iterator.html#ga0fd8c2ec3393e1c695a174266819b464":[17,0,0,10,8],
 "group__iterator.html#ga0ffb6b0a2bf51d1868d9ae7a848eea3b":[17,0,0,10,10],
 "group__iterator.html#ga10d1557457c18e36836976b57d1d5e31":[17,0,0,10,6],
+"group__iterator.html#ga1212f256b9a22aadcbef2e46bccb43e1":[17,0,0,10,20],
 "group__iterator.html#ga15966ac285c94c98c62a5ddec9b1b74b":[17,0,0,10,3],
-"group__iterator.html#ga3e6fd997aece23034c84a70d8a5bf8af":[17,0,0,10,26],
-"group__iterator.html#ga555a29712034196f2d192ce71d6e00e2":[17,0,0,10,17],
+"group__iterator.html#ga32f62dbe9edc2c2af9569b35b6924c48":[17,0,0,10,19],
+"group__iterator.html#ga3e6fd997aece23034c84a70d8a5bf8af":[17,0,0,10,30],
+"group__iterator.html#ga555a29712034196f2d192ce71d6e00e2":[17,0,0,10,21],
 "group__iterator.html#ga5785d3a72289cdb850c24b5e0aa7100d":[17,0,0,10,12],
-"group__iterator.html#ga63d7fbb862216897a9b5a89f98afff76":[17,0,0,10,22],
-"group__iterator.html#ga704b390a7433cb09dd63f689b0655e77":[17,0,0,10,23],
-"group__iterator.html#ga711c5960eb2f7ff4070e37f838f4074e":[17,0,0,10,24],
+"group__iterator.html#ga63d7fbb862216897a9b5a89f98afff76":[17,0,0,10,26],
+"group__iterator.html#ga704b390a7433cb09dd63f689b0655e77":[17,0,0,10,27],
+"group__iterator.html#ga711c5960eb2f7ff4070e37f838f4074e":[17,0,0,10,28],
+"group__iterator.html#ga7355101747302433dd4c5225b295f15c":[17,0,0,10,18],
 "group__iterator.html#ga844a8c9517117f0300e3c7a739f5df8e":[17,0,0,10,0],
 "group__iterator.html#ga9d0bfbbdecc5b19adb08554472b0bae1":[17,0,0,10,2],
 "group__iterator.html#gaabb964cf0f231e5ff977eb00c7d29574":[17,0,0,10,5],
-"group__iterator.html#gab26e8371cd0de4070a5be0ddae72a183":[17,0,0,10,19],
+"group__iterator.html#gab26e8371cd0de4070a5be0ddae72a183":[17,0,0,10,23],
 "group__iterator.html#gab6ba2c375966595a585df6ce1082cdb4":[17,0,0,10,4],
-"group__iterator.html#gabf78b44fef4c4144c757ff5b1c6d75eb":[17,0,0,10,18],
-"group__iterator.html#gac4fd5173563e9d147f10a40561e8634e":[17,0,0,10,14],
-"group__iterator.html#gacaf05e5385011f5dff6e3481dc00c6c4":[17,0,0,10,27],
+"group__iterator.html#gabf78b44fef4c4144c757ff5b1c6d75eb":[17,0,0,10,22],
+"group__iterator.html#gac4fd5173563e9d147f10a40561e8634e":[17,0,0,10,15],
+"group__iterator.html#gacaf05e5385011f5dff6e3481dc00c6c4":[17,0,0,10,31],
 "group__iterator.html#gacd3de1f23a9a5f61cafde7556f728d38":[17,0,0,10,13],
 "group__iterator.html#gad0fc6320ed75e801c486b625e36f3720":[17,0,0,10,1],
-"group__iterator.html#gae0f0c7ed898db72486cc15d95cfe7453":[17,0,0,10,21],
-"group__iterator.html#gaea86b74116ae4155098f7d1474cb9907":[17,0,0,10,16],
+"group__iterator.html#gadf98e12e485781a0d94c7288b3023a03":[17,0,0,10,14],
+"group__iterator.html#gae0f0c7ed898db72486cc15d95cfe7453":[17,0,0,10,25],
+"group__iterator.html#gaea86b74116ae4155098f7d1474cb9907":[17,0,0,10,17],
 "group__iterator.html#gaf2ddc0cd2627c323528b09972b49cf6f":[17,0,0,10,9],
 "group__iterator.html#gaf397097438fb4d4ef56c80e146ed2b20":[17,0,0,10,11],
-"group__iterator.html#gaf7eaa06935320489d166f8cc6dbeab7d":[17,0,0,10,25],
-"group__iterator.html#gaf7fc838d24f7e95b99d0d45639605802":[17,0,0,10,20],
+"group__iterator.html#gaf7eaa06935320489d166f8cc6dbeab7d":[17,0,0,10,29],
+"group__iterator.html#gaf7fc838d24f7e95b99d0d45639605802":[17,0,0,10,24],
 "group__iterator.html#gaf941bec2128ec248c6b0851dbbcbb1ef":[17,0,0,10,7],
-"group__iterator.html#gafa429eb0d3cc208f5d0cb4c0369ad440":[17,0,0,10,15],
+"group__iterator.html#gafa429eb0d3cc208f5d0cb4c0369ad440":[17,0,0,10,16],
 "group__liveliness.html":[17,0,0,4,4],
 "group__liveliness.html#ga18d74e43b7cb8e48849279b7bbec15ce":[17,0,0,4,4,7],
 "group__liveliness.html#ga5f1d4da341587ee934179c6f5b9ce3a6":[17,0,0,4,4,3],
@@ -249,5 +247,7 @@ var NAVTREEINDEX5 =
 "group__paths.html#gabc56f61e16c18b6fa9c277f24d15e2ee":[17,0,0,4,6,9],
 "group__paths.html#gaccdbd4513a066d700cfd44908c580dd0":[17,0,0,4,6,17],
 "group__paths.html#gad52b6adaed6f42f3b93034add7675d07":[17,0,0,4,6,8],
-"group__paths.html#gad844d853ccadef9c5fc11531fa0d9cf8":[17,0,0,4,6,2]
+"group__paths.html#gad844d853ccadef9c5fc11531fa0d9cf8":[17,0,0,4,6,2],
+"group__paths.html#gad96f125e1b4b1b58583efe7d88e6443b":[17,0,0,4,6,0],
+"group__paths.html#gae55232c75245e640f36cd73e5dcf7a8b":[17,0,0,4,6,1]
 };
